@@ -41,6 +41,7 @@
 #include <cutter/cut-console-diff-writer.h>
 #include <cutter/cut-console.h>
 #include <cutter/cut-enum-types.h>
+#include <cutter/cut-utils.h>
 
 #define CUT_TYPE_CONSOLE_UI            cut_type_console_ui
 #define CUT_CONSOLE_UI(obj)            (G_TYPE_CHECK_INSTANCE_CAST ((obj), CUT_TYPE_CONSOLE_UI, CutConsoleUI))
@@ -1126,6 +1127,18 @@ run_notify_command (CutConsoleUI *console, gchar **args)
     }
 }
 
+static gchar *
+format_notify_message (CutRunContext *run_context)
+{
+    CutTestResultStatus status;
+
+    status = cut_run_context_get_status(run_context);
+    return g_strdup_printf("%s [%g%%] (%gs)",
+                           status_to_label(status),
+                           compute_pass_percentage(run_context),
+                           cut_run_context_get_elapsed(run_context));
+}
+
 static void
 notify_by_growlnotify (CutConsoleUI *console, CutRunContext *run_context,
                        gboolean success)
@@ -1133,12 +1146,28 @@ notify_by_growlnotify (CutConsoleUI *console, CutRunContext *run_context,
     GPtrArray *args;
     CutTestResultStatus status;
     gchar *icon_path;
+    gchar *message;
 
     status = cut_run_context_get_status(run_context);
     icon_path = search_icon_path(status, success);
+    message = format_notify_message(run_context);
 
     args = g_ptr_array_new();
     g_ptr_array_add(args, g_strdup(console->notify_command));
+#ifdef G_OS_WIN32
+    g_ptr_array_add(args, g_strdup_printf("/t:\"%s\"", message));
+    g_free(message);
+    if (success) {
+        g_ptr_array_add(args, g_strdup("/p:0"));
+    } else {
+        g_ptr_array_add(args, g_strdup("/p:2"));
+    }
+    if (icon_path) {
+        g_ptr_array_add(args, g_strdup_printf("/i:\"%s\"", icon_path));
+        g_free(icon_path);
+    }
+    g_ptr_array_add(args, format_summary(run_context));
+#else
     g_ptr_array_add(args, g_strdup("--message"));
     g_ptr_array_add(args, format_summary(run_context));
     g_ptr_array_add(args, g_strdup("--priority"));
@@ -1151,11 +1180,8 @@ notify_by_growlnotify (CutConsoleUI *console, CutRunContext *run_context,
         g_ptr_array_add(args, g_strdup("--image"));
         g_ptr_array_add(args, icon_path);
     }
-    g_ptr_array_add(args,
-                    g_strdup_printf("%s [%g%%] (%gs)",
-                                    status_to_label(status),
-                                    compute_pass_percentage(run_context),
-                                    cut_run_context_get_elapsed(run_context)));
+    g_ptr_array_add(args, message);
+#endif
     g_ptr_array_add(args, NULL);
 
     run_notify_command(console, (gchar **)args->pdata);
@@ -1190,11 +1216,7 @@ notify_by_notify_send (CutConsoleUI *console, CutRunContext *run_context,
         g_ptr_array_add(args, g_strdup("--icon"));
         g_ptr_array_add(args, icon_path);
     }
-    g_ptr_array_add(args,
-                    g_strdup_printf("%s [%g%%] (%gs)",
-                                    status_to_label(status),
-                                    compute_pass_percentage(run_context),
-                                    cut_run_context_get_elapsed(run_context)));
+    g_ptr_array_add(args, format_notify_message(run_context));
     summary = format_summary(run_context);
     g_ptr_array_add(args, g_markup_escape_text(summary, -1));
     g_free(summary);
